youtube-dl-GUI
==============

Yet another `youtube-dl` frontend written in python 3.7 and Qt5  

ScreenShot:
-------------
![youtube-dl-gui Screenshot in Ubuntu](http://imgur.com/KxTLeYl.png)

Installation:
------------
`pip install youtube-dl-gui`